@@ -7,38 +7,107 @@ use warnings;
 our @ISA=("Music::Note");
 use Music::Note;
 
+sub new {
+	my ($class,@args)=@_;
+
+	our $self={};
+	our $base=440;
+	
+	if (ref($args[0]) =~/HASH/) {
+		if (defined($args[0]->{base}) && $args[0]->{base} =~ /^\d+$/) {
+			$base=$args[0]->{base};
+			delete $args[0]->{base};
+		}
+		
+		$self=Music::Note->new($args[0]);
+	} elsif (scalar(@args) > 0) {
+		#my $type='ISO';
+		#my $step='C'; my $alter=0;my $octave=4;
+		$base=pop @args;
+		if ($base !~ /^\d*\.?\d*$/ ||  $base !~ /\d/ || $base < 0) {
+			push @args, $base;
+			$base=440;
+		};
+		$self=Music::Note->new(@args);
+	} else {
+		$self=Music::Note->new();
+	}
+
+	$self->{base}=$base;
+
+	bless $self,$class;
+	return $self;
+}
+	
+
 =head1 NAME
 
 Music::Note::Frequency - returns the note's frequency in Hertz (Hz).
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
 
     use Music::Note::Frequency;
 
-        # 'new' is inherited from Music::Note
-        my $note = Music::Note::Frequency->new("C4","ISO");
+	# create a new note object at C4 with base frequency A4=440 Hz.
+	my $note = Music::Note::Frequency->new();
 
+	# all of these create a new object with note = C4 and base 
+        #   frequency A4=431 Hz (default is 440):
+        my $note = Music::Note::Frequency->new(431); 
+        my $note = Music::Note::Frequency->new("C4",431); 
+        my $note = Music::Note::Frequency->new("C4","ISO",431); 
+        my $note = Music::Note::Frequency->new({   step=>'C',
+                                                   alter=>0,
+                                                   octave=>4,
+                                                   base=>431});
+        my $note = Music::Note::Frequency->new({base=>431});
+	
+
+        # get the frequency of a note
+        my $note = Music::Note::Frequency->new("C4");
         print $note->frequency(); # prints 261.625565300599
+        # change the note's base frequency
+	my $base=$note->base(431); # sets new base to 431 Hz
+	print $note->frequency(); # prints 256.274133283086
+
 
 =head1 DESCRIPTION
 
-This module extends Music::Note to provide a method to return the frequency in Hertz (Hz) of the object's note from an equal-tempered tuning.  The formula for calculating frequency values was taken from L<https://en.wikipedia.org/wiki/Piano_key_frequencies> and modified to support MIDI pitch values instead of piano key numbers:
+This module extends Music::Note to provide a method to return the frequency in Hertz (Hz) of the object's note from an equal-tempered tuning.  The formula for calculating frequency values was taken from L<https://en.wikipedia.org/wiki/Piano_key_frequencies> and modified to support MIDI pitch values instead of piano key numbers and alternative base frequencies:
 
-        f(n) = 2**((n - 69)/12) * 440 Hz
+        f(n) = 2**((n - 69)/12) * base
 
         
 
 =head1 METHODS
 
+=head2 new()
+
+=head2 new(NOTE)
+
+=head2 new(NOTE,TYPE)
+
+=head2 new(NOTE,TYPE,BASE)
+
+=head2 new(NOTE,BASE)
+
+=head2 new(BASE)
+
+=head2 new(\%args)
+
+Creates and returns a Music::Note::Frequency object with the values specified in the arguments or defaults of note value = C4 and frequency base (value of A4) = 440 Hz.  Otherwise takes the same arguments as described in the perldoc for Music::Note, with the addition of BASE as an optional (last) numeric argument or as a key/value pair in the passed argument hashref.  Example:
+
+        my $note = Music::Note::Frequency->new({step=>'C',octave=>4,base=>415});
+
 =head2 frequency()
 
 Returns the frequency in Hertz (Hz) of the note from an equal-tempered tuning.  Calculates the frequency from the above formula.  Supports all note types that are supported by Music::Note.
@@ -50,15 +119,33 @@ sub frequency {
         my $self = shift;
         my $n=$self->to_midinum();
 	
-	my $f=440 * 2**(($n-69)/12);
+	my $f=$self->{base} * 2**(($n-69)/12);
 
         return $f;
 };
 
+=head2 base()
+
+=head2 base(FREQ)
+
+Sets or gets the base frequency, i.e. the value of A4 (the A above middle C).  This defaults to 440 when you create the note object without specifying a base frequency.  If called without any parameters, it simply returns the currently set base frequency (from which all other frequencies are calculated).  If called with a numeric parameter, then it sets the base frequency to that value and returns the same.  If FREQ is not numeric, then it doesn't set anything - it just returns the current base frequency.
+
+=cut
+
+sub base {
+	my $self = shift;
+	my $base = shift || undef;
+
+	if (defined($base) && $base =~ /^\d*\.?\d*$/ &&  $base =~ /\d/ && $base >= 0) {
+		$self->{base}=$base;
+	}  
+	return $self->{base};
+}
+
 
 =head1 ACKNOWLEDGEMENTS
 
-Special thanks to Ben Daglish, the author of Music::Note L<http://search.cpan.org/dist/Music-Note/>, and Wikipedia for source material: L<https://en.wikipedia.org/wiki/Piano_key_frequencies>.
+Special thanks to Ben Daglish, the author of Music::Note L<http://search.cpan.org/dist/Music-Note/>, both for his original module and his suggestion to allow setting the base frequency, and Wikipedia for source material: L<https://en.wikipedia.org/wiki/Piano_key_frequencies>.
 
 
 =head1 AUTHOR
